# Overview

Welcome to the 🤗 Datasets tutorial!

The goal of the tutorials are to help new users build up a basic understanding of 🤗 Datasets. You will learn to:

* Setup a virtual environment and install 🤗 Datasets.
* Load a dataset.
* Explore what's inside a Dataset object.
* Use a dataset with PyTorch and TensorFlow.
* Evaluate your model predictions with a metric.
* Easily upload a dataset to the Hugging Face Hub.

After completing the tutorials, we hope you will have the necessary skills to start using our library in your own projects!

We understand that people who want to use 🤗 Datasets come from a wide and diverse range of disciplines. The tutorials are designed to be as accessible as possible to people without a developer background. If you already have some experience, take a look at our [Quick Start](../quickstart.rst) to see an end-to-end code example in context.